==> gristle-0.0.0.tgz: package/README.md <==
# Gristle CSS

Gristle is an ultra-lightweight, responsive CSS grid system.

## Notable features

- tiny foot print (~1KB)
- small surface area
- multi-level, responsive collapsing
- free and open-source

## Getting Gristle

Gristle is available through [NPM](https://www.npmjs.com/package/gristle), via [releases](https://github.com/garydouble/gristle/releases) or as [source code](https://github.com/garydouble/gristle).

*CDN availability coming soon...*

### Distributed Files

Both development and production files are provided within the `'dist'` directory, including source maps:

`gristle.css`  
Uncompressed development version.

`gristle.min.css`  
Minified production version.

## Quick Start

Link to a Gristle stylesheet between your `<head>` tags:

    <head>
      <title>...</title>
      <link rel="stylesheet" href="path/to/gristle[.min].css" />
      ...
    </head>

Add a Gristle grid element to your `<body>` tag and define some column structures:

    <body>
      <div class="gsl-grid">
        <div class="gsl-1">Large full-width column</div>

        <div class="gsl-2">Left half column</div>
        <div class="gsl-2">Right half column</div>

        <div class="gsl-3">try</div>
        <div class="gsl-3">some</div>
        <div class="gsl-3">thirds</div>

        ...
      </div>
    </body>

## But wait! Gristle has so much more to offer...

Check out the [documentation](http://garydouble.com/gristle) for more details, examples and information.  
E.G: grid nesting, row support, non-collapsible columns, Etc.

## Contributions

*Gristle is free, open-source software.* ([MIT](https://raw.githubusercontent.com/garydouble/gristle/master/LICENSE))

[Issues](https://github.com/garydouble/gristle/issues),
[feedback](mailto:garydouble@live.com) and
[pull requests](https://github.com/garydouble/gristle) all welcome.  
Happy Coding!

==> gristle-1.0.0.tgz: package/README.md <==
# Gristle

Gristle is an ultra-lightweight, responsive CSS grid system.

## Notable features

- tiny foot print (~1KB)
- small surface area
- multi-level, responsive collapsing
- moderately opinionated
- free and open-source

## Getting Gristle

Gristle is available through [NPM](https://www.npmjs.com/package/gristle), via [releases](https://github.com/garydouble/gristle/releases) or as [source code](https://github.com/garydouble/gristle).

*CDN availability coming soon...*

### Distributed Files

Both development and production files are provided within the `'dist'` directory, including source maps:

`gristle.css`  
Uncompressed development version.

`gristle.min.css`  
Minified production version.

## Quick Start

Link to a Gristle stylesheet between your `<head>` tags:

    <head>
      <title>...</title>
      <link rel="stylesheet" href="path/to/gristle[.min].css" />
      ...
    </head>

Add a Gristle grid element to your `<body>` tag and define some column structures:

    <body>
      <div class="gristle-grid">
        <div>
          <div class="c12">full-width column</div>
        </div>
        <div>
          <div class="c6">lhs half column</div>
          <div class="c6">rhs half column</div>
        </div>
        <div>
          <div class="c4">try</div>
          <div class="c4">some</div>
          <div class="c4">thirds</div>
        </div>
        ...
      </div>
    </body>

## But wait! Gristle has so much more to offer...

Check out the [documentation](http://garydouble.com/gristle) for more examples and information.

## Contributions

*Gristle is free, open-source software.* ([MIT](https://raw.githubusercontent.com/garydouble/gristle/master/LICENSE))

[Issues](https://github.com/garydouble/gristle/issues),
[feedback](mailto:garydouble@live.com) and
[pull requests](https://github.com/garydouble/gristle) all welcome.  
Happy Coding!
